pub struct StateTimelineView;Trait Implementations
Sourceimpl Default for StateTimelineView
impl Default for StateTimelineView
Sourcefn default() -> StateTimelineView
fn default() -> StateTimelineView
Returns the “default value” for a type. Read more
Sourceimpl ViewClass for StateTimelineView
impl ViewClass for StateTimelineView
Sourcefn identifier() -> ViewClassIdentifier
fn identifier() -> ViewClassIdentifier
Identifier string of this view class. Read more
Sourcefn display_name(&self) -> &'static str
fn display_name(&self) -> &'static str
User-facing name of this view class. Read more
Sourcefn is_experimental(&self) -> bool
fn is_experimental(&self) -> bool
Whether this view class is still experimental. Read more
Sourcefn new_state(&self) -> Box<dyn ViewState>
fn new_state(&self) -> Box<dyn ViewState>
Called once for every new view instance of this class. Read more
fn help(&self, _os: OperatingSystem) -> Help
Sourcefn on_register(
&self,
system_registry: &mut ViewSystemRegistrator<'_>,
) -> Result<(), ViewClassRegistryError>
fn on_register( &self, system_registry: &mut ViewSystemRegistrator<'_>, ) -> Result<(), ViewClassRegistryError>
Called once upon registration of the class Read more
Sourcefn preferred_tile_aspect_ratio(&self, _state: &dyn ViewState) -> Option<f32>
fn preferred_tile_aspect_ratio(&self, _state: &dyn ViewState) -> Option<f32>
Preferred aspect ratio for the ui tiles of this view.
Sourcefn layout_priority(&self) -> ViewClassLayoutPriority
fn layout_priority(&self) -> ViewClassLayoutPriority
Controls how likely this view will get a large tile in the ui.
Sourcefn spawn_heuristics(
&self,
ctx: &ViewerContext<'_>,
include_entity: &dyn Fn(&EntityPath) -> bool,
) -> ViewSpawnHeuristics
fn spawn_heuristics( &self, ctx: &ViewerContext<'_>, include_entity: &dyn Fn(&EntityPath) -> bool, ) -> ViewSpawnHeuristics
Determines which views should be spawned by default for this class. Read more
Sourcefn selection_ui(
&self,
_ctx: &ViewerContext<'_>,
_ui: &mut Ui,
_state: &mut dyn ViewState,
_space_origin: &EntityPath,
_view_id: ViewId,
) -> Result<(), ViewSystemExecutionError>
fn selection_ui( &self, _ctx: &ViewerContext<'_>, _ui: &mut Ui, _state: &mut dyn ViewState, _space_origin: &EntityPath, _view_id: ViewId, ) -> Result<(), ViewSystemExecutionError>
Ui shown when the user selects a view of this class.
Sourcefn ui(
&self,
ctx: &ViewerContext<'_>,
_missing_chunk_reporter: &MissingChunkReporter,
ui: &mut Ui,
state: &mut dyn ViewState,
query: &ViewQuery<'_>,
system_output: SystemExecutionOutput,
) -> Result<(), ViewSystemExecutionError>
fn ui( &self, ctx: &ViewerContext<'_>, _missing_chunk_reporter: &MissingChunkReporter, ui: &mut Ui, state: &mut dyn ViewState, query: &ViewQuery<'_>, system_output: SystemExecutionOutput, ) -> Result<(), ViewSystemExecutionError>
Draws the ui for this view class and handles ui events. Read more
Sourcefn recommendation_order(&self) -> i32
fn recommendation_order(&self) -> i32
Ordering hint for view class recommendations. Lower values are recommended more. Read more
Sourcefn supports_visible_time_range(&self) -> bool
fn supports_visible_time_range(&self) -> bool
Controls whether the visible time range UI should be displayed for this view.
Sourcefn default_query_range(&self, _state: &(dyn ViewState + 'static)) -> QueryRange
fn default_query_range(&self, _state: &(dyn ViewState + 'static)) -> QueryRange
Default query range for this view.
Sourcefn recommended_origin_for_entities(
&self,
entities: &HashSet<EntityPath, BuildHasherDefault<NoHashHasher<EntityPath>>>,
_entity_db: &EntityDb,
) -> Option<EntityPath>
fn recommended_origin_for_entities( &self, entities: &HashSet<EntityPath, BuildHasherDefault<NoHashHasher<EntityPath>>>, _entity_db: &EntityDb, ) -> Option<EntityPath>
Determines a suitable origin given the provided set of entities. Read more
Sourcefn recommended_visualizers_for_entity(
&self,
entity_path: &EntityPath,
visualizers_with_reason: &[(ViewSystemIdentifier, &VisualizableReason)],
indicated_entities_per_visualizer: &PerVisualizerType<&IndicatedEntities>,
) -> RecommendedVisualizers
fn recommended_visualizers_for_entity( &self, entity_path: &EntityPath, visualizers_with_reason: &[(ViewSystemIdentifier, &VisualizableReason)], indicated_entities_per_visualizer: &PerVisualizerType<&IndicatedEntities>, ) -> RecommendedVisualizers
Auto picked visualizers for an entity if there was not explicit selection. Read more
Sourcefn visualizers_section<'a>(
&'a self,
_ctx: &'a ViewContext<'a>,
) -> Option<VisualizersSectionOutput<'a>>
fn visualizers_section<'a>( &'a self, _ctx: &'a ViewContext<'a>, ) -> Option<VisualizersSectionOutput<'a>>
Custom UI and add-visualizer options for the “Visualizers” section in the selection panel. Read more
Sourcefn extra_title_bar_ui(
&self,
_ctx: &ViewerContext<'_>,
_ui: &mut Ui,
_state: &mut (dyn ViewState + 'static),
_space_origin: &EntityPath,
_view_id: BlueprintId<ViewIdRegistry>,
) -> Result<(), ViewSystemExecutionError>
fn extra_title_bar_ui( &self, _ctx: &ViewerContext<'_>, _ui: &mut Ui, _state: &mut (dyn ViewState + 'static), _space_origin: &EntityPath, _view_id: BlueprintId<ViewIdRegistry>, ) -> Result<(), ViewSystemExecutionError>
Additional UI displayed in the tab title bar, between the “maximize” and “help” buttons. Read more